@@ -1,14 +1,18 @@
-#coding:utf-8
-'''
-Модуль работы с метаролями пользователей. На уровне Платформы объявлены следующие метароли:
+# coding:utf-8
+u"""
+Метароли пользователей
+======================
+
+На уровне Платформы объявлены следующие метароли:
+
  - Супер-администратор -- может создавать других администраторов и назначать им права доступа
  - Администратор -- выполняет административные функции
  - Обобщенный пользователь -- любой пользователь системы
 
-Created on 17.06.2010
+.. Created on 17.06.2010
 
-@author: akvarats
-'''
+.. @author: akvarats
+"""
 
 import threading
 
@@ -22,82 +26,87 @@ from m3_legacy import logger
 
 
 class UserMetarole(object):
-    '''
+    u"""
     Класс, описывающий метароль пользователя
-    '''
-    def __init__(self, metarole_code, metarole_name):
-        # код метароли пользователя
-        self.code = metarole_code
-        self.name = metarole_name
-        self.included_metaroles = []
+    """
 
+    def __init__(self, metarole_code, metarole_name):
+        #: кодовое обозначение метароли пользователя
+        self.code = metarole_code
+        #: название метароли пользователя
+        self.name = metarole_name
+        #: список метаролей, дети данной метароли
+        self.included_metaroles = []
 
     @property_json_encode
     def id(self):
-        """
+        u"""
         геттер необходим для лучшей маскировки объекта Метароли под объект обычной модели
         (критично для некоторых операций Dict_Pack'ов)
         """
         return self.code
-    
 
     def get_owner_metaroles(self):
-        '''
+        u"""
         Возвращает список метаролей в которые входит наша метароль. Проще говоря список родителей,
         ребенком которых является наша метароль. 
-        '''
+        """
         result = []
+        # TODO: может сразу исключить self из запроса?
         for role in metarole_manager._metaroles.values():
             if (role != self) and (self in role.included_metaroles):
                 result.append(role)
         return result
-    
+
     def __str__(self):
         """ Более наглядное представление для отладки """
-        return u'%s: %s at %s' % (self.code, self.name, id(self)) 
-        
+        return u'%s: %s at %s' % (self.code, self.name, id(self))
+
+
 class MetaroleManager(object):
-    '''
+    u"""
     Менеджер метаролей пользователя
-    '''
+    """
+
     def __init__(self):
         self._loaded = False
         self._write_lock = threading.RLock()
         self._metaroles = {}
-        
+
     def register_metarole(self, metarole):
-        '''
+        u"""
         Регистрирует метароль в менеджере ролей
-        '''
+        """
         self._metaroles[metarole.code] = metarole
-        
+
     def get_metarole(self, code):
-        '''
+        u"""
         Возвращает экземпляр метароли по коду
-        '''
+        """
         self._populate()
+        # TODO: можно обойтись return self._metaroles.get(code)
         if self._metaroles.has_key(code):
             return self._metaroles[code]
         return None
-    
+
     def get_registered_metaroles(self):
-        '''
+        u"""
         Возвращает экземпляры всех зарегистроированных в системе метаролей
-        '''
+        """
         self._populate()
         return sorted(self._metaroles.values(), key=lambda metarole: metarole.name)
-    
+
     def _populate(self):
-        '''
+        u"""
         Собирает метароли по объявленным приложениям
-        '''
+        """
         if self._loaded:
             return
         self._write_lock.acquire()
         try:
             if self._loaded:
                 return
-            
+
             for app_name in settings.INSTALLED_APPS:
                 try:
                     module = import_module('.app_meta', app_name)
@@ -118,8 +127,6 @@ class MetaroleManager(object):
             raise
         finally:
             self._write_lock.release()
-        
-
 
 
 #------------------------------------------------------------------------------ 
@@ -149,16 +156,23 @@ metarole_manager = MetaroleManager()
 get_metarole = metarole_manager.get_metarole
 get_metaroles = metarole_manager.get_registered_metaroles
 
+
 #===============================================================================
 # Пакет действий для метаролей
 #===============================================================================
 
 class Metaroles_DictPack(BaseDictionaryActions):
+    u"""
+    Пакет действий с метаролями
+    """
     url = '/metarole'
     title = u'Метароли системы'
     list_columns = [('name', u'Наименование метароли')]
     list_readonly = True
-                    
+
+    # TODO: переименовать filter
+    # TODO: многие параметры не используются. тогда зачем они?
+    # TODO: вместо find, нельзя ли использовать in?
     def get_rows(self, offset, limit, filter, user_sort=''):
         data = []
         for role in metarole_manager.get_registered_metaroles():
@@ -169,11 +183,18 @@ class Metaroles_DictPack(BaseDictionaryActions):
             else:
                 data.append(role)
         return {'rows': data}
-    
+
     def get_row(self, id):
+        u"""
+        возвращает метароль по id
+        """
         return metarole_manager.get_metarole(id)
-    
+
     def get_select_window(self, win):
-        # Доступно 1 событие: выбор с присвоением значения вызвавшему контролу
+        u"""
+        возвращает окно выбора метароли
+
+        .. note:: Доступно 1 событие: выбор с присвоением значения вызвавшему контролу
+        """
         win.column_name_on_select = 'name'
         return win
