@@ -1,4 +1,4 @@
-#coding:utf-8
+# coding:utf-8
 '''
 Created on 11.06.2010
 
@@ -12,17 +12,12 @@ from m3.actions import (urls,
                         ActionPack,
                         ACD,
                         ControllerCache,
-                        ActionContext,)
+                        ActionContext, )
 from m3.actions.results import PreJsonResult, JsonResult, OperationResult
 from m3.actions.packs import BaseDictionaryModelActions
 
-from m3_ext.ui import windows
-from m3_ext.ui import panels
-from m3_ext.ui import fields
-from m3_ext.ui import controls
-from m3_ext.ui import helpers as ui_helpers
+from m3_ext.ui import windows, panels, fields, controls, helpers as ui_helpers
 from m3_ext.ui.fields.complex import ExtSearchField
-from m3_ext.ui.panels.grids import ExtObjectGrid
 from m3_ext.ui.containers import ExtTree, ExtTreeNode
 from m3_ext.ui.results import ExtUIScriptResult, ExtGridDataQueryResult
 
@@ -31,90 +26,164 @@ from m3_legacy import logger
 try:
     from m3_audit.manager import AuditManager
     from m3_audit.models import RolesAuditModel
+
     _M3_AUDIT_INSTALLED = True
 except ImportError:
     _M3_AUDIT_INSTALLED = False
 
 from users import SelectUsersListWindow
+from ui import RolesListWindow, RolesEditWindow
 import helpers
 import models
-import metaroles
-import app_meta
 import api
 
 PERM_OBJECT_NOT_FOUND = u'** объект права не найден **'
 
+
 class RolesActions(ActionPack):
-    '''
+    """
     Пакет действий для подсистемы прав пользователей
-    '''
+    """
 
     url = '/roles'
 
+    list_win = RolesListWindow
+    edit_win = RolesEditWindow
+    select_win = SelectUsersListWindow
+
     def __init__(self):
         super(RolesActions, self).__init__()
-        self.actions = [
-            RolesWindowAction(),
-            EditRoleWindowAction(),
-            SaveRoleAction(),
-            DeleteRoleAction(),
+
+        self.roles_window_action = RolesWindowAction()
+        self.edit_role_window_action = EditRoleWindowAction()
+        self.save_role_action = SaveRoleAction()
+        self.delete_role_action = DeleteRoleAction()
+        # показ окна со списком пользователей, ассоциированных с ролью
+        self.show_assigned_users_action = ShowAssignedUsersAction()
+        # получение списка пользователей, ассоциированных с ролью
+        self.role_assigned_users_data_action = RoleAssignedUsersDataAction()
+        # получение окна со списком пользователей,
+        # которые можно добавить в роль
+        self.select_users_to_assign_window = SelectUsersToAssignWindowAction()
+        # получение списка пользователей,
+        # которых можно включить в заданную роль
+        self.users_for_role_assignment_data = UsersForRoleAssignmentData()
+        self.roles_data_action = RolesDataAction()
+        # действие на добавление пользователей в роль
+        self.assign_users = AssignUsers()
+        # удаление связанного с ролью пользователя
+        self.delete_assigned_user = DeleteAssignedUser()
+        # получение списка прав доступа роли
+        self.get_role_permission_action = GetRolePermissionAction()
+        # выбор прав доступа для добавления в роль
+        self.add_role_permission = AddRolePermission()
+        self.actions.extend([
+            self.roles_window_action,
+            self.edit_role_window_action,
+            self.save_role_action,
+            self.delete_role_action,
+            self.show_assigned_users_action,
+            self.role_assigned_users_data_action,
+            self.select_users_to_assign_window,
+            self.users_for_role_assignment_data,
+            self.roles_data_action,
+            self.assign_users,
+            self.delete_assigned_user,
+            self.get_role_permission_action,
+            self.add_role_permission
+        ])
+
+    def _get_list_win_grid_urls(self):
+        return {
+            'url_data': self.roles_data_action.get_absolute_url(),
+            'url_new': self.edit_role_window_action.get_absolute_url(),
+            'url_edit': self.edit_role_window_action.get_absolute_url(),
+            'url_delete': self.delete_role_action.get_absolute_url(),
+            'url_show_assigned_users': (
+                self.show_assigned_users_action.get_absolute_url()),
+            'show_assigned_users': self.show_assigned_users_action
+        }
+
+    def create_list_win(self):
+        win = self.list_win()
+
+        params = self._get_list_win_grid_urls()
+        win.configure_grid(**params)
+
+        return win
+
+    def _get_edit_win_params(self):
+        return {
+            'url_data': self.get_role_permission_action.get_absolute_url(),
+            'url_new': self.add_role_permission.get_absolute_url(),
+            'form_url': self.save_role_action.get_absolute_url()
+        }
+
+    def create_edit_win(self, new_role, user_role):
+        win = self.edit_win(new_role=new_role)
+
+        params = self._get_edit_win_params()
+        win.configure_window(user_role, **params)
+
+        return win
+
+    def create_select_win(self, role):
+        win = self.select_win()
+        win.grid.url_data = (
+            self.users_for_role_assignment_data.get_absolute_url())
+        win.grid.title = u"Выберите пользователей для роли '%s'" % role.name
+        win.action_submit = self.assign_users
+
+        return win
 
 
-            ShowAssignedUsersAction(), # показ окна со списком пользователей, ассоциированных с ролью
-            RoleAssignedUsersDataAction(), # получение списка пользователей, ассоциированных с ролью
-            SelectUsersToAssignWindowAction(), # получение окна со списком пользователей, которые можно добавить в роль
-            UsersForRoleAssignmentData(), # получение списка пользователей, которых можно включить в заданную роль
-            RolesDataAction(),
-            AssignUsers(), # действие на добавление пользователей в роль
-            DeleteAssignedUser(), # удаление связанного с ролью пользователя
-            GetRolePermissionAction(), # получение списка прав доступа роли
-            AddRolePermission(), # выбор прав доступа для добавления в роль
-            #GetAllPermissions(), # получение дерева всех прав доступа
-        ]
-
-#===============================================================================
+# =============================================================================
 # UI actions
-#  - RolesWindowAction -- получение окна со списком ролей
-#  - EditRoleWindowAction -- получение окна редактирования роли
-#===============================================================================
-
+# - RolesWindowAction -- получение окна со списком ролей
+# - EditRoleWindowAction -- получение окна редактирования роли
+#=============================================================================
 class RolesWindowAction(Action):
-    '''
+    """
     Действие на получение окна показа списка пользовательских ролей
-    '''
+    """
     url = '/roles-window'
 
     def run(self, request, context):
-        return ExtUIScriptResult(data=RolesListWindow())
+        win = self.parent.create_list_win()
+
+        return ExtUIScriptResult(data=win)
+
 
 class EditRoleWindowAction(Action):
-    '''
+    """
     Получение окна редактирования роли пользователя
-    '''
+    """
+
     url = '/edit-role-window'
     need_check_permission = True
     verbose_name = u'Добавление и редактирование роли'
+
     def context_declaration(self):
-        return [
-            ACD(name=u'userrole_id', type=int, required=True, default=0)
-        ]
+        return [ACD(name=u'userrole_id', type=int, required=True, default=0)]
 
     def run(self, request, context):
 
         new_role = True
-        if(context.userrole_id > 0):
+        if context.userrole_id:
             new_role = False
             try:
                 user_role = models.UserRole.objects.get(pk=context.userrole_id)
             except models.UserRole.DoesNotExist:
-                return OperationResult(success=False, message=u'Роль с указанным идентификатором не найдена')
+                return OperationResult(
+                    success=False,
+                    message=u'Роль с указанным идентификатором не найдена')
         else:
             user_role = models.UserRole()
 
-        window = RolesEditWindow(new_role)
-        window.form.from_object(user_role)
+        win = self.parent.create_edit_win(new_role, user_role)
+
+        return ExtUIScriptResult(data=win)
 
-        return ExtUIScriptResult(data=window)
 
 class ShowAssignedUsersAction(Action):
     '''
@@ -134,6 +203,7 @@ class ShowAssignedUsersAction(Action):
 
         return ExtUIScriptResult(window)
 
+
 class SelectUsersToAssignWindowAction(Action):
     '''
     Показ окна с выбором сотрудников, которые не были выбраны ранее для указанной роли
@@ -149,37 +219,30 @@ class SelectUsersToAssignWindowAction(Action):
 
     def run(self, request, context):
         role = models.UserRole.objects.get(id=context.userrole_id)
-        window = SelectUsersListWindow()
-        window.grid.action_data = UsersForRoleAssignmentData
-        window.grid.title = u"Выберите пользователей для роли '%s'" % role.name
-        window.action_submit = AssignUsers
 
-        return ExtUIScriptResult(window)
+        win = self.parent.create_select_win(role)
+
+        return ExtUIScriptResult(win)
+
 
 class AddRolePermission(Action):
-    '''
+    """
     Выбор прав доступа для добавления в роль
-    '''
+    """
     url = '/role-add-permission-window'
     need_check_permission = True
     verbose_name = u'Добавление прав'
-#    def context_declaration(self):
-#        return [
-#            actions.ActionContextDeclaration(name='userrole_id', type=int, required=True)
-#        ]
-#
+
     def run(self, request, context):
-        #role = models.UserRole.objects.get(id=context.userrole_id)
         window = SelectPermissionWindow()
-        #window.title = u"Выберите права доступа для роли '%s'" % role.name
         return ExtUIScriptResult(window)
 
+
 #===============================================================================
 # DATA actions
 #===============================================================================
 
 class RolesDataAction(Action):
-
     url = '/roles-data'
 
     def context_declaration(self):
@@ -190,7 +253,9 @@ class RolesDataAction(Action):
         ]
 
     def run(self, request, context):
-        return JsonResult(ui_helpers.paginated_json_data(helpers.get_roles_query(context.filter), context.start, context.limit))
+        return JsonResult(
+            ui_helpers.paginated_json_data(helpers.get_roles_query(context.filter), context.start, context.limit))
+
 
 class RoleAssignedUsersDataAction(Action):
     '''
@@ -208,7 +273,9 @@ class RoleAssignedUsersDataAction(Action):
 
     def run(self, request, context):
         filter = getattr(context, 'filter', None)
-        return ExtGridDataQueryResult(helpers.get_assigned_users_query(context.userrole_id, filter), context.start, context.limit)
+        return ExtGridDataQueryResult(helpers.get_assigned_users_query(context.userrole_id, filter), context.start,
+                                      context.limit)
+
 
 class UsersForRoleAssignmentData(Action):
     '''
@@ -231,6 +298,7 @@ class UsersForRoleAssignmentData(Action):
         return PreJsonResult({'rows': rows, 'total': total})
         #return actions.ExtGridDataQueryResult(helpers.get_unassigned_users(context.userrole_id, context.filter))
 
+
 class GetRolePermissionAction(Action):
     '''
     Получение списка прав доступа для указанной роли
@@ -265,13 +333,15 @@ class GetRolePermissionAction(Action):
                     pack_name = act.parent.get_verbose_name()
                 else:
                     pack_name = act.get_verbose_name()
-                perm.verbose_name = '%s - %s' % (pack_name, act.verbose_name if act.verbose_name else act.__class__.__name__)
+                perm.verbose_name = '%s - %s' % (
+                    pack_name, act.verbose_name if act.verbose_name else act.__class__.__name__)
                 if sub_code and sub_code in act.sub_permissions:
                     perm.verbose_name = '%s - %s' % (pack_name, act.sub_permissions[sub_code])
             res.append(perm)
         res.sort(key=lambda o: o.verbose_name)
         return ExtGridDataQueryResult(res)
 
+
 def get_all_permission_tree():
     '''
     Общий подход к формированию дерева прав доступа (алгоритм):
@@ -279,8 +349,9 @@ def get_all_permission_tree():
     у каждого элемента списка прав должен быть путь в дереве (пока строкой), наименование права доступа, полное наименование права (для грида прав)
     путь в дереве строится из значения path элемента, а если он отсутствует, то по иерархии этого элемента в фактической структуре действий и набора действий
     '''
+
     class PermProxy(ExtTreeNode):
-        def __init__(self, id, parent=None, name='', url='', can_select=True, fullname=None, path = ''):
+        def __init__(self, id, parent=None, name='', url='', can_select=True, fullname=None, path=''):
             super(PermProxy, self).__init__()
             self.parent = parent
             if parent:
@@ -305,7 +376,7 @@ def get_all_permission_tree():
         '''
         parent_node = None
         if path:
-            items = path.strip().split("\\") #.replace("/", "\\")
+            items = path.strip().split("\\")  #.replace("/", "\\")
             for name in items:
                 node = find_node(name, parent_node, res)
                 if not node:
@@ -319,7 +390,7 @@ def get_all_permission_tree():
         if action:
             if sub_perm_code in action.sub_permissions.keys():
                 path = action.sub_permissions[sub_perm_code]
-                items = path.strip().split("\\") #.replace("/", "\\")
+                items = path.strip().split("\\")  #.replace("/", "\\")
                 # если длина пути больше 1, значит указали путь - выделим путь и имя
                 if len(items) > 1:
                     name = items[-1]
@@ -347,7 +418,7 @@ def get_all_permission_tree():
         if actionpack:
             if sub_perm_code in actionpack.sub_permissions.keys():
                 path = actionpack.sub_permissions[sub_perm_code]
-                items = path.strip().split("\\") #.replace("/", "\\")
+                items = path.strip().split("\\")  #.replace("/", "\\")
                 # если длина пути больше 1, значит указали путь - выделим путь и имя
                 if len(items) > 1:
                     name = items[-1]
@@ -403,13 +474,7 @@ def get_all_permission_tree():
             # обработаем подчиненные Наборы
             for pack in action_set.subpacks:
                 add_nodes(None, pack, res, ctrl)
-            # удалим созданные элементы, если небыло дочерних
-            #if len(res) - count == 0:
-                #res.remove(item)
-            #    while len(res) > start_count:
-            #        item = res.pop()
-            #        if item.parent:
-            #            item.parent.children.remove(item)
+
         # если передали Действие
         elif isinstance(action_set, Action):
             if action_set.need_check_permission or action_set.sub_permissions:
@@ -420,7 +485,7 @@ def get_all_permission_tree():
                     pack_name = pack.get_verbose_name()
                 else:
                     pack_name = ''
-                #name = action_set.verbose_name if action_set.verbose_name else action_set.__class__.__name__
+
                 name = action_set.get_verbose_name()
                 fullname = '%s - %s' % (pack_name, name)
                 if action_set.need_check_permission:
@@ -446,6 +511,7 @@ def get_all_permission_tree():
                         child3 = PermProxy(len(res) + 1, None, name, url, True, fullname, path)
                         res.append(child3)
                         res_urls[url] = item
+
     res = []
     res_urls = {}
     # пройдемся по контроллерам
@@ -468,6 +534,7 @@ def get_all_permission_tree():
             nodes.append(item)
     return nodes
 
+
 #===============================================================================
 # OPERATIONS
 #===============================================================================
@@ -487,7 +554,7 @@ class SaveRoleAction(Action):
 
     def run(self, request, context):
         try:
-            if(context.userrole_id > 0):
+            if (context.userrole_id > 0):
                 try:
                     user_role = models.UserRole.objects.get(id=context.userrole_id)
                 except models.UserRole.DoesNotExist:
@@ -542,7 +609,7 @@ class SaveRoleAction(Action):
                         role=user_role,
                         permission_or_code=i.permission_code,
                         type=RolesAuditModel.PERMISSION_REMOVAL)
-            # end
+                    # end
         except:
             logger.exception(u'Не удалось сохранить роль пользователя')
             return OperationResult(success=False, message=u'Не удалось сохранить роль пользователя.')
@@ -550,7 +617,7 @@ class SaveRoleAction(Action):
         return OperationResult(success=True)
 
     def _get_role(self, request, context):
-        if(context.userrole_id > 0):
+        if (context.userrole_id > 0):
             try:
                 user_role = models.UserRole.objects.get(id=context.userrole_id)
             except models.UserRole.DoesNotExist:
@@ -595,12 +662,11 @@ class SaveRoleAction(Action):
         return result
 
 
-
 class DeleteRoleAction(Action):
-
     url = '/delete-role'
     need_check_permission = True
     verbose_name = u'Удаление роли'
+
     def context_declaration(self):
         return [
             ACD(name=u'userrole_id', type=int, required=True)
@@ -613,18 +679,22 @@ class DeleteRoleAction(Action):
             return OperationResult(success=False, message=u'Роль с указанным идентификатором не найдена')
 
         if len(helpers.get_assigned_users_query(user_role)) > 0:
-            return OperationResult(success=False, message=u'К данной роли привязаны пользователи. Удалять такую роль нельзя')
+            return OperationResult(success=False,
+                                   message=u'К данной роли привязаны пользователи. Удалять такую роль нельзя')
 
         try:
             if not safe_delete(user_role):
                 # FIXME: return в try - это зло
-                return OperationResult(success=False, message=u'Не удалось удалить роль пользователя.<br>На эту запись есть ссылки в базе данных.')
+                return OperationResult(success=False,
+                                       message=u'Не удалось удалить роль пользователя.<br>На эту запись есть ссылки в базе данных.')
         except:
             logger.exception(u'Не удалось удалить роль пользователя')
-            return OperationResult(success=False, message=u'Не удалось удалить роль пользователя.<br>Подробности в логах системы.')
+            return OperationResult(success=False,
+                                   message=u'Не удалось удалить роль пользователя.<br>Подробности в логах системы.')
 
         return OperationResult(success=True)
 
+
 class AssignUsers(Action):
     '''
     Сопоставление пользователей роли
@@ -658,7 +728,8 @@ class AssignUsers(Action):
             logger.exception(u'Не удалось добавить список пользователей в роль')
 
             return OperationResult(success=False, message=u'Не удалось добавить пользователей в роль')
-        return OperationResult(success=True,)
+        return OperationResult(success=True, )
+
 
 class DeleteAssignedUser(Action):
     '''
@@ -667,6 +738,7 @@ class DeleteAssignedUser(Action):
     url = '/delete-assigned-user'
     need_check_permission = True
     verbose_name = u'Удаление пользователя роли'
+
     def context_declaration(self):
         return [
             ACD(name='assigneduser_id', type=ActionContext.ValuesList(), required=True)
@@ -677,8 +749,8 @@ class DeleteAssignedUser(Action):
             try:
                 assigned_user = models.AssignedRole.objects.get(id=assigneduser_id)
             except models.AssignedRole.DoesNotExist:
-                return OperationResult(success=False, message=u'Не удалось удалить запись. Указанный пользователь не найден.')
-
+                return OperationResult(success=False,
+                                       message=u'Не удалось удалить запись. Указанный пользователь не найден.')
 
             try:
                 api.remove_user_role(assigned_user.user, assigned_user.role)
@@ -686,104 +758,18 @@ class DeleteAssignedUser(Action):
                 logger.exception()
                 return OperationResult.by_message(u'Не удалось удалить запись. Подробности в логах системы.')
 
-
         return OperationResult()
 
+
 #===============================================================================
 # UI
 #===============================================================================
 
-class RolesListWindow(windows.ExtWindow):
-
-    def __init__(self, *args, **kwargs):
-        super(RolesListWindow, self).__init__(*args, **kwargs)
-
-        self.title = u'Роли пользователей'
-        self.layout = 'fit'
-        self.width = 540
-        self.height = 500
-        self.template_globals = 'm3-users/roles-list-window.js'
-
-        #=======================================================================
-        # Настройка грида со списком ролей
-        #=======================================================================
-        self.grid = panels.ExtObjectGrid()
-        self.grid.add_column(header=u'Наименование роли', data_index='name', width=300)
-        self.grid.add_column(header=u'Метароль', data_index='metarole_name', width=240)
-        self.items.append(self.grid)
-
-        self.grid.action_data = RolesDataAction
-        self.grid.action_new = EditRoleWindowAction
-        self.grid.action_edit = EditRoleWindowAction
-        self.grid.action_delete = DeleteRoleAction
-        self.grid.top_bar.button_new.text = u'Добавить новую роль'
-        self.grid.top_bar.items.append(controls.ExtButton(text=u'Показать пользователей', icon_cls='search', handler='contextMenu_ShowAssignedUsers'))
-        self.grid.row_id_name = 'userrole_id'
-
-        # дополнительные действия формы
-        self.grid.action_show_assigned_users = ShowAssignedUsersAction
-
-        self.grid.context_menu_row.add_item(text=u'Показать пользователей', icon_cls='user-icon-16', handler='contextMenu_ShowAssignedUsers')
-        #self.grid.context_menu_row.add_item(text = u'Показать разрешения роли', icon_cls = 'edit_item', handler='contextMenu_ShowPermissions')
-        self.grid.context_menu_row.add_separator()
-
-
-        self.init_component(*args, **kwargs)
-
-class RolesEditWindow(windows.ExtEditWindow):
-    '''
-    Окно редактирования роли
-    '''
-
-    def __init__(self, new_role=False, *args, **kwargs):
-        super(RolesEditWindow, self).__init__(*args, **kwargs)
-
-        self.width = 500
-        self.height = 400
-        self.modal = True
-
-        self.new_role = new_role
-
-        self.template_globals = 'm3-users/edit-role-window.js'
-
-        self.title = u'Роль пользователя'
-        self.layout = 'border'
-        self.form = panels.ExtForm(layout='form', region='north', height=60, style={'padding': '5px'})
-        self.form.label_width = 100
-        self.form.url = SaveRoleAction.absolute_url()
-
-        field_name = fields.ExtStringField(name='name', label=u'Наименование', allow_blank=False, anchor='100%')
-        field_metarole = fields.ExtDictSelectField(name='metarole', label=u'Метароль', anchor='100%', hide_trigger=False)
-        field_metarole.configure_by_dictpack(metaroles.Metaroles_DictPack, app_meta.users_controller)
-        field_metarole.editable = False
-        field_metarole.hide_dict_select_trigger = True
-
-        self.form.items.extend([field_name, field_metarole])
-
-        self.grid = ExtObjectGrid(title=u"Права доступа", region="center")
-        self.grid.action_data = GetRolePermissionAction
-        self.grid.action_new = AddRolePermission
-        self.grid.top_bar.items.append(controls.ExtButton(text=u'Удалить', icon_cls='delete_item', handler='deletePermission'))
-        self.grid.top_bar.button_refresh.hidden = True
-        self.grid.force_fit = True
-        self.grid.allow_paging = False
-        self.grid.row_id_name = 'permission_code'
-        self.grid.store.id_property = 'permission_code'
-        self.grid.store.auto_save = False
-        #self.grid.add_column(header=u'Действие', data_index='permission_code', width=100)
-        self.grid.add_column(header=u'Разрешенные права', data_index='verbose_name', width=100)
-        self.grid.add_bool_column(header=u'Запрет', data_index='disabled', width=50, text_false=u'Нет', text_true=u'Да', hidden=True)
-        self.items.append(self.grid)
-
-        self.buttons.extend([
-            controls.ExtButton(text=u'Сохранить', handler='submitForm'),
-            controls.ExtButton(text=u'Отмена', handler='cancelForm')
-        ])
-
 class AssignedUsersWindow(windows.ExtWindow):
     '''
     Окно просмотра пользователей, которые включены в данную роль
     '''
+
     def __init__(self, *args, **kwargs):
         super(AssignedUsersWindow, self).__init__(*args, **kwargs)
         self.title = u'Пользователи, с указанной ролью'
@@ -792,8 +778,10 @@ class AssignedUsersWindow(windows.ExtWindow):
         self.modal = True
 
         self.layout = 'border'
-        self.panel_north = panels.ExtForm(layout='form', region='north', height=40, label_width=50, style={'padding': '5px'})
-        self.panel_center = panels.ExtPanel(layout='fit', region='center', body_cls='x-window-mc', title=u'Пользователи с данной ролью', style={'padding': '5px'})
+        self.panel_north = panels.ExtForm(layout='form', region='north', height=40, label_width=50,
+                                          style={'padding': '5px'})
+        self.panel_center = panels.ExtPanel(layout='fit', region='center', body_cls='x-window-mc',
+                                            title=u'Пользователи с данной ролью', style={'padding': '5px'})
 
         self.items.extend([
             self.panel_north,
@@ -813,7 +801,7 @@ class AssignedUsersWindow(windows.ExtWindow):
         self.grid_users.add_column(header=u'E-mail', data_index='user_email', width=200)
         self.grid_users.action_data = RoleAssignedUsersDataAction
 
-        search_text_grid = ExtSearchField(empty_text = u'Поиск', component_for_search = self.grid_users)
+        search_text_grid = ExtSearchField(empty_text=u'Поиск', component_for_search=self.grid_users)
         self.grid_users.top_bar.add_fill()
         self.grid_users.top_bar.items.append(search_text_grid)
 
@@ -829,13 +817,14 @@ class AssignedUsersWindow(windows.ExtWindow):
         self.grid_users.row_id_name = 'assigneduser_id'
         self.panel_center.items.append(self.grid_users)
 
-
         self.buttons.append(controls.ExtButton(text=u'Закрыть', handler='closeWindow'))
 
+
 class SelectPermissionWindow(windows.ExtEditWindow):
     '''
     Окно выбора прав доступа для добавления в роль
     '''
+
     def __init__(self, *args, **kwargs):
         super(SelectPermissionWindow, self).__init__(*args, **kwargs)
         self.title = u'Выберите права доступа для роли'
@@ -873,4 +862,4 @@ class Roles_DictPack(BaseDictionaryModelActions):
     list_columns = [('name', u'Наименование'), ]
     edit_window = RolesEditWindow
     filter_fields = ['name']
-    list_readonly = True # справочник - только для выбора из него
+    list_readonly = True  # справочник - только для выбора из него
